@@ -23,6 +23,22 @@ Check your ``PROJECT_DIR/setup.cfg`` contains::
     copyright = 2020, Otosense
     display_name = Epythet
 
+For graphviz support:
+
+For MacOS::
+
+    brew install graphviz
+
+For Ubuntu::
+
+    sudo apt-get install graphviz
+
+For Windows::
+
+    Install windows package from: https://graphviz.gitlab.io/_pages/Download/Download_windows.html
+    Add C:\Program Files (x86)\Graphviz2.38\bin to User path
+    Add C:\Program Files (x86)\Graphviz2.38\bin\dot.exe to System Path
+
 3-in-1 Quickstart
 =================
 
